pub struct FormatTable { /* private fields */ }Expand description
The format table for key=value pairs used when rendering Arguments, like in format()
Implementations
Sourceimpl FormatTable
impl FormatTable
Sourcepub fn render(&self, template: &Template<'_>) -> String
pub fn render(&self, template: &Template<'_>) -> String
Renders a template to a string, replacing tags with values from the table
pub fn render_string( &self, str: impl AsRef<str>, ) -> Result<String, TemplateError>
Sourcepub fn add_entry(&mut self, key: impl Into<String>, value: impl Into<String>)
pub fn add_entry(&mut self, key: impl Into<String>, value: impl Into<String>)
Adds a single key=value pair to the table
Sourcepub fn add_table<I, K, V>(&mut self, table: I)
pub fn add_table<I, K, V>(&mut self, table: I)
Extends the table with an iterator of key=value pairs